@@ -5,7 +5,7 @@ Define globals types used by the code.
 """
 
 # noinspection PyUnresolvedReferences
-from typing import Union, TYPE_CHECKING, List, Dict, Tuple, Optional
+from typing import Union, TYPE_CHECKING, List, Dict, Tuple, Optional, Any
 
 # Types
 NumberType = Union[int, float]
